# CarDEC

CarDEC (**C**ount **a**dapted **r**egulared **D**eep **E**mbedded **C**lustering) is a joint deep learning computational tool that is useful for analyses of single-cell RNA-seq data. CarDEC can be used to:
1. Correct for batch effect in the full gene expression space, allowing the investigator remove batch effect from downstream analyses like psuedotime analysis and coexpression analysis. Batch correction is also possible in a low-dimensional embedding space.
2. Denoise gene expression.
3. Cluster cells.

## Installation

Please install CarDEC from the python package index as follows.

```
$ pip install CarDEC
```

## Usage

A [tutorial jupyter notebook](https://drive.google.com/drive/folders/19VVOoq4XSdDFRZDou-VbTMyV2Na9z53O?usp=sharing), together with a dataset, is publicly downloadable.